[java-identity-provider COMMIT] in /trunk: idp-authn-api/src/main/java/net/shibboleth/idp/authn/AbstractAuthenticatio...

noreply at shibboleth.net noreply at shibboleth.net
Mon Apr 2 17:37:40 BST 2012


Author: lajoie
Date: Mon Apr  2 17:37:40 2012
New Revision: 4156

URL: http://svn.shibboleth.net/view/java-identity-provider?rev=4156&view=rev
Log:
More authn work

Removed:
    trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/RecoverableAuthenticationException.java
    trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/UnrecoverableAuthenticationException.java
Modified:
    trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AbstractAuthenticationAction.java
    trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AuthenticationException.java
    trunk/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/DisplayUsernamePasswordPage.java
    trunk/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/ExtractUserAgentAddress.java
    trunk/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/ExtractUsernamePasswordFromBasicAuthorizationHeader.java
    trunk/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/ExtractUsernamePasswordFromFormResponse.java
    trunk/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/ExtractUsernamePasswordFromWssToken.java
    trunk/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/FinalizeAuthentication.java
    trunk/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/SendBasicHttpAuthenticationChallenge.java
    trunk/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/ValidateUserAgentAddress.java

Modified: trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AbstractAuthenticationAction.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AbstractAuthenticationAction.java?rev=4156&r1=4155&r2=4156&view=diff
==============================================================================
--- trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AuthenticationException.java (original)
+++ trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AuthenticationException.java Mon Apr  2 17:37:40 2012
@@ -17,8 +17,10 @@
 
 package net.shibboleth.idp.authn;
 
+import net.shibboleth.idp.profile.ProfileException;
+
 /** Exception indicating a problem authenticating a user. */
-public class AuthenticationException extends Exception {
+public class AuthenticationException extends ProfileException {
 
     /** Serial version UID. */
     private static final long serialVersionUID = 6587176160411149029L;

Modified: trunk/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/DisplayUsernamePasswordPage.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/DisplayUsernamePasswordPage.java?rev=4156&r1=4155&r2=4156&view=diff

[... 372 lines stripped ...]


More information about the commits mailing list
--- trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AbstractAuthenticationAction.java (original)
+++ trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AbstractAuthenticationAction.java Mon Apr  2 17:37:40 2012
@@ -21,14 +21,14 @@
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
+import net.shibboleth.idp.profile.AbstractIdentityProviderAction;
+import net.shibboleth.idp.profile.ProfileException;
+import net.shibboleth.idp.profile.ProfileRequestContext;
+
 import org.springframework.webflow.execution.Event;
 import org.springframework.webflow.execution.RequestContext;
 
 import com.google.common.base.Function;
-
-import net.shibboleth.idp.profile.AbstractIdentityProviderAction;
-import net.shibboleth.idp.profile.ProfileException;
-import net.shibboleth.idp.profile.ProfileRequestContext;
 
 /** A base class for authentication related actions. */
 public abstract class AbstractAuthenticationAction extends AbstractIdentityProviderAction {
@@ -63,12 +63,12 @@
      * 
      * @return the result of this action
      * 
      * @throws ProfileException thrown if there is a problem executing the profile action
      */
     protected abstract Event doExecute(@Nonnull final HttpServletRequest httpRequest,
             @Nonnull final HttpServletResponse httpResponse, @Nonnull final RequestContext springRequestContext,
             @Nonnull final ProfileRequestContext profileRequestContext,
-            @Nonnull final AuthenticationRequestContext authenticationContext) throws ProfileException;
+            @Nonnull final AuthenticationRequestContext authenticationContext) throws AuthenticationException;
 
     /** Exception thrown if there is no authentication exception available. */
     public static final class NoAuthenticationContextException extends ProfileException {
@@ -63,12 +63,12 @@
      * @return the result of this action
      * 
-     * @throws ProfileException thrown if there is a problem executing the profile action
+     * @throws AuthenticationException thrown if there is a problem performing the authentication action
      */
     protected abstract Event doExecute(@Nonnull final HttpServletRequest httpRequest,

Modified: trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AuthenticationException.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AuthenticationException.java?rev=4156&r1=4155&r2=4156&view=diff
==============================================================================